# Sources

Use Rapporto for acquiring information from different APIs.

```{toctree}
:maxdepth: 1
:hidden:

github
opsgenie
slack
```

::::{grid} 3
:gutter: 4

:::{grid-item-card} GitHub
:link: github
:link-type: doc
:class-card: sd-fs-2
:class-body: sd-text-center
:class-footer: sd-fs-6
{fab}`github;sd-text-grey fa-2xl`
+++
Tap into the GitHub API and generate reports in Markdown format.
:::

:::{grid-item-card} Opsgenie
:link: opsgenie
:link-type: doc
:class-card: sd-fs-2
:class-body: sd-text-center
:class-footer: sd-fs-6
![](https://netdata.cloud/img/opsgenie.png){w=100px}
+++
Tap into the Opsgenie API and generate reports in Markdown format.
:::

:::{grid-item-card} Slack
:link: slack
:link-type: doc
:class-card: sd-fs-2
:class-body: sd-text-center
:class-footer: sd-fs-6
{fab}`slack;sd-text-success fa-2xl`
+++
Tap into the Slack API and export threads into Markdown format.
:::

::::
